/*
 * Copyright  2005 Steve Whitley / NullFX Software
 * 
 * It is a violation of your purchase agreement to remove this text
 * This source may not be redistributed in any way shape or form
 * 
 */
using System;
using System.Net.Security;
using System.Security.Cryptography.X509Certificates;

namespace NullFX.Net {
    /// <summary>
    /// Class used for certificate validation events
    /// </summary>
    public class CertificateValidationEventArgs : EventArgs {
        readonly X509Certificate cert;
        readonly X509Chain chain;
        readonly SslPolicyErrors errors;

        /// <summary>
        /// Gets the certificate
        /// </summary>
        public X509Certificate Certificate {
            get { return cert; }
        }

        /// <summary>
        /// Gets the certificate chain
        /// </summary>
        public X509Chain Chain {
            get { return chain; }
        }

        /// <summary>
        /// Gets the SSL policy errors
        /// </summary>
        public SslPolicyErrors Errors {
            get { return errors; }
        }

        /// <summary>
        /// Gets or Sets whether the certificate is valid and allowable
        /// </summary>
        public bool Allow { get; set; }

        /// <summary>
        /// Creates a new instance of the event args
        /// </summary>
        /// <param name="certificate">the certificate</param>
        /// <param name="chain">the certificate chain</param>
        /// <param name="sslPolicyErrors">SSL policy errors</param>
        public CertificateValidationEventArgs(X509Certificate certificate, X509Chain chain, SslPolicyErrors sslPolicyErrors) {
            cert = certificate;
            this.chain = chain;
            errors = sslPolicyErrors;
            Allow = false;
        }
    }
}
